@@ -15,8 +15,7 @@ function assert(cond, msg) {
 }
 
 // require the generated script which creates the ENUM structure
-var ENUM = {}
-ENUM.ManagedEnum = require('./managedenum.ncd.js')
+var ENUM = require('./test-old-api-wrappers.js')
 
 // import the constant names in the global namespace
 importObject(ENUM.ManagedEnum, ENUM)
