@@ -9,11 +9,11 @@ function importObject(obj, target) {
 }
 
 // require the generated script which creates the ENUM structure
-var ENUM = {}
-ENUM.ManagedEnum = require('./managedenum.ncd.js')
+var ENUM = require('./test-old-api-wrappers.js')
 
 // import the constant and function names in the global namespace
 importObject(ENUM.ManagedEnum, global)
+importObject(ENUM, global)
 
 // print all entries with their names and values
 for (k = 0; k < getNumManagedEnum(); ++k) {
